summaryrefslogtreecommitdiff
path: root/engine/routines/printitemdescription.asm
diff options
context:
space:
mode:
authoryenatch <yenatch@gmail.com>2018-02-03 17:15:20 -0500
committerGitHub <noreply@github.com>2018-02-03 17:15:20 -0500
commitb35eb72290b964b98844afbe741bb7ede34b9ef3 (patch)
tree2cf2652bc9c3e69ae5f7b2a2632c02a12498615f /engine/routines/printitemdescription.asm
parent7547ad839cf1c8141b931d08ef16a894e7db68c9 (diff)
parent32ade4ac9bf113d630d904aab51f2c49c91bf8c2 (diff)
Merge pull request #480 from luckytyphlosion/master
[Ready to merge] Prefix wram labels with w.
Diffstat (limited to 'engine/routines/printitemdescription.asm')
-rw-r--r--engine/routines/printitemdescription.asm10
1 files changed, 5 insertions, 5 deletions
diff --git a/engine/routines/printitemdescription.asm b/engine/routines/printitemdescription.asm
index e6d087dae..2a9007b97 100644
--- a/engine/routines/printitemdescription.asm
+++ b/engine/routines/printitemdescription.asm
@@ -1,23 +1,23 @@
PrintItemDescription: ; 0x1c8955
-; Print the description for item [CurSpecies] at de.
+; Print the description for item [wCurSpecies] at de.
- ld a, [CurSpecies]
+ ld a, [wCurSpecies]
cp TM01
jr c, .not_a_tm
- ld [CurItem], a
+ ld [wCurItem], a
push de
farcall GetTMHMItemMove
pop hl
ld a, [wd265]
- ld [CurSpecies], a
+ ld [wCurSpecies], a
predef PrintMoveDesc
ret
.not_a_tm
push de
ld hl, ItemDescriptions
- ld a, [CurSpecies]
+ ld a, [wCurSpecies]
dec a
ld c, a
ld b, 0